@@ -26,6 +26,7 @@ print "fver_find=$fver_find\n";
 
 my @cpp_rename = (
 "bits/c++0x_warning.h:cxx0x_warning.hxx",
+"bits/c++14_warning.h:cxx14_warning.hxx",
 "bits/exception_defines.h:_excptdef.h",
 "bits/exception_ptr.h:_excptptr.h",
 "bits/hashtable.h:_hashtbl.h",
@@ -694,7 +695,7 @@ sub mk_manifest
         '/include/(?:avx2|bmi2|f16c|fma|lzcnt)intrin.\h$',
         '/include/std(?:align|noreturn)\.h$',
         '/include/quadmath(?:|_weak).h',
-        '/include/(?:stdarg|stdbool|stddef|stdfix|tgmath|unwind|varargs)\.h$',
+        '/include/(?:stdarg|stdatomic|stdbool|stddef|stdfix|tgmath|unwind|varargs)\.h$',
         '/include/header.gcc$',
         '/include-fixed/(?:limits|syslimits|wchar)\.h$',
         '/include-fixed/readme$',
@@ -702,11 +703,14 @@ sub mk_manifest
 	'/include/(?:adx|fxsr|prfchw|rdseed|rtm|xsave|xsaveopt)intrin.h$',
         '/include/cross-stdarg.h$',
         '/include/stdint(?:|-gcc).h$',
+        '/include/avx512[^\.]*.h$',
+        '/include/shaintrin\.h$',
         '/install-tools/', '/libgcc\.a', '/libgcov\.a', '/libssp*',
         '/libquadmath.a',
         '/cc1\.exe',
+        '/lto1\.exe',
         '/collect2\.exe',
-        '/lto-wrapper.exe',
+        '/lto-wrapper\.exe',
         'manifest/gcc',
         'readme.djgpp', '/cat1/(?:cpp|gcc|gcov)', '/cat7/',
         '/bugs', '/copying', '/faq', '/news', '/readme', '/gcc/onews',
